@@ -276,7 +276,7 @@ KVersionControlPlugin::ItemVersion FileViewGitPlugin::itemVersion(const KFileIte
     }
 }
 
-QList<QAction*> FileViewGitPlugin::actions(const KFileItemList &items) const
+QList<QAction*> FileViewGitPlugin::versionControlActions(const KFileItemList& items) const
 {
     if (items.count() == 1 && items.first().isDir()) {
         QString directory = items.first().localPath();
@@ -294,6 +294,13 @@ QList<QAction*> FileViewGitPlugin::actions(const KFileItemList &items) const
     }
 }
 
+QList<QAction*> FileViewGitPlugin::outOfVersionControlActions(const KFileItemList& items) const
+{
+    Q_UNUSED(items)
+
+    return {};
+}
+
 QList<QAction*> FileViewGitPlugin::contextMenuFilesActions(const KFileItemList& items) const
 {
     Q_ASSERT(!items.isEmpty());
