@@ -42,7 +42,8 @@ public:
     bool beginRetrieval(const QString& directory) override;
     void endRetrieval() override;
     ItemVersion itemVersion(const KFileItem& item) const override;
-    QList<QAction*> actions(const KFileItemList& items) const override;
+    QList<QAction*> versionControlActions(const KFileItemList& items) const override;
+    QList<QAction*> outOfVersionControlActions(const KFileItemList& items) const override;
 
 signals:
     /// Invokes m_showUpdatesAction->setChecked(checked) on the UI thread.
@@ -62,6 +63,8 @@ private slots:
     void removeFiles();
     void revertFiles();
     void logDialog();
+    void checkoutDialog();
+    void cleanupDialog();
 
     void slotOperationCompleted(int exitCode, QProcess::ExitStatus exitStatus);
     void slotOperationError();
@@ -115,6 +118,8 @@ private:
     QAction* m_revertAction;
     QAction* m_showUpdatesAction;
     QAction* m_logAction;
+    QAction* m_checkoutAction;
+    QAction* m_cleanupAction;
 
     QString m_command;
     QStringList m_arguments;
